@@ -75,6 +75,93 @@ class _ParseComparison(_Parse):
         return tree.Comparison(left=left, op=op, right=right, original_node=node), None
 
 
+class _ParseAll(_Parse):
+    def matches(self, node: ast.AST) -> bool:
+        return (
+            isinstance(node, ast.Call)
+            and isinstance(node.func, ast.Name)
+            and node.func.id == "all"
+        )
+
+    def transform(self, node: ast.AST) -> Tuple[Optional[tree.Node], Optional[Error]]:
+        assert (
+            isinstance(node, ast.Call)
+            and isinstance(node.func, ast.Name)
+            and node.func.id == "all"
+        )
+
+        if len(node.keywords) > 0:
+            return None, Error(
+                node,
+                "Expected no keyword arguments in ``all``, "
+                f"but got {len(node.keywords)}",
+            )
+
+        if len(node.args) != 1:
+            return None, Error(
+                node,
+                "Expected exactly one argument in ``all``, "
+                f"but got {len(node.args)}",
+            )
+
+        if not isinstance(node.args[0], ast.GeneratorExp):
+            return None, Error(
+                node,
+                "Expected a generator expression in ``all``, "
+                f"but got: {ast.dump(node)}",
+            )
+
+        generator_exp = node.args[0]
+
+        condition, error = ast_node_to_our_node(generator_exp.elt)
+        if error is not None:
+            return None, error
+
+        assert isinstance(condition, tree.Expression), f"{condition=}"
+
+        if len(generator_exp.generators) != 1:
+            return None, Error(
+                node,
+                "Expected exactly one generator in ``all``, "
+                f"but got {len(generator_exp.generators)}",
+            )
+
+        generator = generator_exp.generators[0]
+        if not isinstance(generator, ast.comprehension):
+            return None, Error(
+                generator, f"Expected a comprehension, but got: {ast.dump(generator)}"
+            )
+
+        if not isinstance(generator.target, ast.Name):
+            return None, Error(
+                generator,
+                f"Expected the target of the generator to be a name, "
+                f"but got: {ast.dump(generator.target)}",
+            )
+
+        variable, error = ast_node_to_our_node(generator.target)
+        if error is not None:
+            return None, error
+        assert isinstance(variable, tree.Name), f"{variable=}"
+
+        an_iter, error = ast_node_to_our_node(generator.iter)
+        if error is not None:
+            return None, error
+
+        assert isinstance(an_iter, tree.Expression), f"{an_iter=}"
+
+        return (
+            tree.All(
+                for_each=tree.ForEach(
+                    variable=variable, iteration=an_iter, original_node=generator
+                ),
+                condition=condition,
+                original_node=node,
+            ),
+            None,
+        )
+
+
 class _ParseCall(_Parse):
     def matches(self, node: ast.AST) -> bool:
         return isinstance(node, ast.Call)
@@ -273,71 +360,6 @@ class _ParseAndOrOr(_Parse):
             raise AssertionError(f"Unexpected: {node.op=}")
 
 
-class _ParseExpressionWithDeclaration(_Parse):
-    def matches(self, node: ast.AST) -> bool:
-        return (
-            isinstance(node, ast.Subscript)
-            and isinstance(node.value, ast.Tuple)
-            and len(node.value.elts) == 2
-            and isinstance(node.value.elts[0], ast.NamedExpr)
-            and isinstance(node.slice, ast.Index)
-            and isinstance(node.slice.value, ast.Constant)
-            and node.slice.value.value == 1
-        )
-
-    def transform(self, node: ast.AST) -> Tuple[Optional[tree.Node], Optional[Error]]:
-        assert (
-            isinstance(node, ast.Subscript)
-            and isinstance(node.value, ast.Tuple)
-            and len(node.value.elts) == 2
-            and isinstance(node.value.elts[0], ast.NamedExpr)
-            and isinstance(node.slice, ast.Index)
-            and isinstance(node.slice.value, ast.Constant)
-            and node.slice.value.value == 1
-        )
-
-        declaration, error = ast_node_to_our_node(node.value.elts[0])
-        if error is not None:
-            return None, error
-
-        assert isinstance(declaration, tree.Declaration), f"{declaration=}"
-
-        expression, error = ast_node_to_our_node(node.value.elts[1])
-        if error is not None:
-            return None, error
-
-        assert isinstance(expression, tree.Expression), f"{expression=}"
-
-        return (
-            tree.ExpressionWithDeclarations(
-                declarations=[declaration], expression=expression, original_node=node
-            ),
-            None,
-        )
-
-
-class _ParseDeclaration(_Parse):
-    def matches(self, node: ast.AST) -> bool:
-        return isinstance(node, ast.NamedExpr) and isinstance(node.target, ast.Name)
-
-    def transform(self, node: ast.AST) -> Tuple[Optional[tree.Node], Optional[Error]]:
-        assert isinstance(node, ast.NamedExpr) and isinstance(node.target, ast.Name)
-
-        value, error = ast_node_to_our_node(node.value)
-        if error is not None:
-            return None, error
-
-        assert value is not None
-        assert isinstance(value, tree.Expression), f"{value=}"
-
-        return (
-            tree.Declaration(
-                identifier=Identifier(node.target.id), value=value, original_node=node
-            ),
-            None,
-        )
-
-
 class _ParseExpression(_Parse):
     def matches(self, node: ast.AST) -> bool:
         return isinstance(node, ast.Expr)
@@ -463,6 +485,7 @@ class _ParseReturn(_Parse):
 
 _CHAIN_OF_RULES = [
     _ParseComparison(),
+    _ParseAll(),
     _ParseCall(),
     _ParseConstant(),
     _ParseImplication(),
@@ -470,8 +493,6 @@ _CHAIN_OF_RULES = [
     _ParseName(),
     _ParseIsNoneOrIsNotNone(),
     _ParseAndOrOr(),
-    _ParseExpressionWithDeclaration(),
-    _ParseDeclaration(),
     _ParseExpression(),
     _ParseJoinedStr(),
     _ParseAssignment(),
