@@ -1,3 +1,5 @@
+# pylint: disable=missing-docstring
+
 import contextlib
 import io
 import os
@@ -9,9 +11,11 @@ import aas_core_codegen.main
 
 
 class Test_against_recorded(unittest.TestCase):
-    # Set this variable to True if you want to re-record the test data,
-    # without any checks
-    RERECORD = False
+    RERECORD = os.environ.get("AAS_CORE_CODEGEN_RERECORD", "").lower() in (
+        "1",
+        "true",
+        "on",
+    )
 
     def test_cases(self) -> None:
         repo_dir = pathlib.Path(os.path.realpath(__file__)).parent.parent.parent
@@ -39,7 +43,9 @@ class Test_against_recorded(unittest.TestCase):
                         expected_output_dir.exists() and expected_output_dir.is_dir()
                     ), expected_output_dir
 
-                    tmp_dir = tempfile.TemporaryDirectory()
+                    tmp_dir = (
+                        tempfile.TemporaryDirectory()  # pylint: disable=consider-using-with
+                    )
                     exit_stack.push(tmp_dir)
                     output_dir = pathlib.Path(tmp_dir.name)
 
@@ -73,10 +79,12 @@ class Test_against_recorded(unittest.TestCase):
                 )
 
                 if Test_against_recorded.RERECORD:
-                    stdout_pth.write_text(normalized_stdout)
+                    stdout_pth.write_text(normalized_stdout, encoding="utf-8")
                 else:
                     self.assertEqual(
-                        normalized_stdout, stdout_pth.read_text(), stdout_pth
+                        normalized_stdout,
+                        stdout_pth.read_text(encoding="utf-8"),
+                        stdout_pth,
                     )
 
                 # BEFORE-RELEASE (mristin, 2021-12-13):
@@ -85,6 +93,7 @@ class Test_against_recorded(unittest.TestCase):
                     pathlib.Path("types.cs"),
                     pathlib.Path("visitation.cs"),
                     pathlib.Path("verification.cs"),
+                    pathlib.Path("reporting.cs"),
                     pathlib.Path("stringification.cs"),
                     pathlib.Path("jsonization.cs"),
                     # BEFORE-RELEASE (mristin, 2021-12-19):
